'use strict';

export default class Likes {

	constructor(_container) {
		this._container = _container;
		this._likeButton = this._container.querySelector('.btn');
		this._numberOfLikes = this._likeButton.querySelector('.tx-sgnews-number-of-likes-value')
		this._newsId = this._container.dataset.uid;
		this._setupEventListener();
		this._checkButtonsStatus();
	}

	_setupEventListener() {
		this._likeButton.addEventListener('click', this._addLike.bind(this));
	}

	/**
	 * Fires the Ajax-Call to add a new Like
	 * Won't do anything if the user already committed a like
	 */
	_addLike() {
		if (!window.localStorage.getItem('sg-news-like-' + this._newsId)) {
			this._likeButton.classList.add('tx-sgnews-loading');
			const request = new XMLHttpRequest();
			request.onreadystatechange = () => {
				if (request.readyState === XMLHttpRequest.DONE) {
					if (request.status === 200) {
						const data = JSON.parse(request.responseText);
						this._likeButton.classList.remove('tx-sgnews-loading');
						if (data.success) {
							window.localStorage.setItem('sg-news-like-' + this._newsId, true);
							this._updateButton(true);
						}
					}
				}
			};
			request.open(
				'POST',
				'?eID=sgAjax&extensionName=SgNews&controller=Ajax\\Like&action=addLike&format=json'
			);
			request.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
			request.send(`parameters[newsPid]=${this._newsId }`);
		}
	}

	/**
	 * Checks if the user already committed a like and updates the button accordingly
	 */
	_checkButtonsStatus() {
		if (window.localStorage.getItem('sg-news-like-' + this._newsId)) {
			this._updateButton(false);
		}
	}

	/**
	 * Update the like-button status
	 *
	 * @param {bool} addedLike If set to true, the like-count will also be increased
	 */
	_updateButton(addedLike) {
		this._likeButton.classList.remove('btn-info');
		this._likeButton.classList.add('btn-success');
		const star = this._likeButton.querySelector('.fa-star-o');
		star.classList.remove('fa-star-o');
		star.classList.add('fa-star');
		this._likeButton.blur();
		if (addedLike) {
			const currentValue = parseInt(this._numberOfLikes.textContent);
			this._numberOfLikes.textContent = currentValue + 1;
		}
	}
}
